@@ -4,9 +4,10 @@ import os
 from typing import List, Union, Any
 
 import humanize
-
+import select
+import sys
 from fds.logger import Logger
-
+import PyInquirer
 
 def get_size_of_path(path: str) -> int:
     if os.path.isdir(path):
@@ -24,10 +25,31 @@ def convert_bytes_to_string(bytes_data: bytes) -> str:
 
 
 def execute_command(command: Union[str, List[str]], shell: bool = False, capture_output: bool = True,
-                    ignorable_return_codes: List[int] = [0]) -> Any:
+                    ignorable_return_codes: List[int] = [0], capture_output_and_write_to_stdout: bool = False) -> Any:
     if capture_output:
         # capture_output is not available in python 3.6, so using PIPE manually
         output = subprocess.run(command, shell=shell, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    elif capture_output_and_write_to_stdout:
+        output = subprocess.Popen(command, shell=shell, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+        stdout=[]
+        stderr=[]
+        while True:
+            reads = [output.stdout.fileno(), output.stderr.fileno()]
+            ret = select.select(reads, [], [])
+
+            for fd in ret[0]:
+                if fd == output.stdout.fileno():
+                    read = output.stdout.readline()
+                    sys.stdout.write(convert_bytes_to_string(read))
+                    stdout.append(read)
+                if fd == output.stderr.fileno():
+                    read = output.stderr.readline()
+                    sys.stderr.write(convert_bytes_to_string(read))
+                    stderr.append(read)
+            if output.poll() != None:
+                break
+        # create a completed process to have same convention
+        return subprocess.CompletedProcess(command, output.returncode, b''.join(stdout), b''.join(stderr))
     else:
         output = subprocess.run(command, shell=shell)
     if output.stderr is None or output.stdout is None:
@@ -87,3 +109,21 @@ def construct_dvc_url_from_git_url_dagshub(git_url: str) -> str:
     :return: The dvc url
     """
     return git_url.replace(".git", ".dvc")
+
+
+def get_input_from_user(question: str, type: str = "input") -> str:
+    """
+    Get input from user
+    :param question: The question to ask user
+    :param type: The type of input
+    :return: output from the user
+    """
+    questions = [
+        {
+            'type': type,
+            'message': question,
+            'name': 'question'
+        }
+    ]
+    answers = PyInquirer.prompt(questions)
+    return answers['question']
