@@ -20,7 +20,7 @@ class TestGit(IntegrationTestCase):
     def test_add(self):
         self.git_service.init()
         super().create_fake_git_data()
-        self.git_service.add(".", [])
+        self.git_service.add(["."], [])
         output = execute_command(["git", "status"], capture_output=True)
         assert convert_bytes_to_string(output.stderr) == ""
         assert "new file:   git_data/file-0" in convert_bytes_to_string(output.stdout)
@@ -32,7 +32,7 @@ class TestGit(IntegrationTestCase):
     def test_skip(self):
         self.git_service.init()
         super().create_fake_git_data()
-        self.git_service.add(".", ["./git_data"])
+        self.git_service.add(["."], ["./git_data"])
         output = execute_command(["git", "status"], capture_output=True)
         assert convert_bytes_to_string(output.stderr) == ""
         # This means untracked file
@@ -42,7 +42,7 @@ class TestGit(IntegrationTestCase):
     def test_add_one(self):
         self.git_service.init()
         super().create_fake_git_data()
-        self.git_service.add("git_data/file-0", [])
+        self.git_service.add(["git_data/file-0"], [])
         output = execute_command(["git", "status"], capture_output=True)
         assert convert_bytes_to_string(output.stderr) == ""
         assert "new file:   git_data/file-0" in convert_bytes_to_string(output.stdout)
@@ -52,11 +52,24 @@ class TestGit(IntegrationTestCase):
         assert "file-3" in convert_bytes_to_string(output.stdout)
         assert "file-4" in convert_bytes_to_string(output.stdout)
 
+    def test_add_multiple(self):
+        self.git_service.init()
+        super().create_fake_git_data()
+        self.git_service.add(["git_data/file-0", "git_data/file-1", "git_data/file-3"], [])
+        output = execute_command(["git", "status"], capture_output=True)
+        assert convert_bytes_to_string(output.stderr) == ""
+        assert "new file:   git_data/file-0" in convert_bytes_to_string(output.stdout)
+        assert "new file:   git_data/file-1" in convert_bytes_to_string(output.stdout)
+        assert "new file:   git_data/file-3" in convert_bytes_to_string(output.stdout)
+        assert "Untracked files:" in convert_bytes_to_string(output.stdout)
+        assert "file-2" in convert_bytes_to_string(output.stdout)
+        assert "file-4" in convert_bytes_to_string(output.stdout)
+
     def test_add_gitignore(self):
         self.git_service.init()
         super().create_fake_git_data()
         super().create_dummy_file(".gitignore", 100)
-        self.git_service.add("git_data/file-0", [])
+        self.git_service.add(["git_data/file-0"], [])
         output = execute_command(["git", "status"], capture_output=True)
         assert "new file:   git_data/file-0" in convert_bytes_to_string(output.stdout)
         assert "new file:   .gitignore" in convert_bytes_to_string(output.stdout)
@@ -64,7 +77,7 @@ class TestGit(IntegrationTestCase):
     def test_commit(self):
         self.git_service.init()
         super().create_fake_git_data()
-        self.git_service.add(".", [])
+        self.git_service.add(["."], [])
         self.git_service.commit("Commit 1")
         output = execute_command(["git", "log", "--oneline"], capture_output=True)
         assert "Commit 1" in convert_bytes_to_string(output.stdout)
